@@ -220,6 +220,15 @@ var options = {};
 <!-- jsChart -->  
 <script type="text/javascript\" src="https://www.google.com/jsapi?callback=displayChart%s"></script>
 '
+  
+'
+<script src="https://www.gstatic.com/charts/loader.js"></script>
+<script>
+  google.charts.load(\'current\', {packages: [\'corechart\']});
+  google.charts.setOnLoadCallback(drawChart);
+</script><script src="googleCharts/bindings.js"></script>
+'  
+  
   jsChart  <- sprintf(jsChart, chartid)
   
   
@@ -458,6 +467,11 @@ gvisCheckData <- function(data="", options=list(), data.structure=list()){
                                      names(options$data) != "allowed" &
                                      names(options$data) != "date.format"])]
   
+  html.tooltip.col <- names(data)[endsIn(names(data), '.tooltip')]
+  if (length(html.tooltip.col) == 1) {
+    x[[html.tooltip.col]] <- data[[html.tooltip.col]]
+  }
+  
   sapply(names(options$data[options$data!="" & names(options$data) !=
                               "allowed" & names(options$data) != "date.format"]), 
          function(.x){ 
@@ -539,9 +553,8 @@ gvisOptions <- function(options=list(gvis=list(width = 600, height=500))){
   #print(options)
   .par <- sapply(names(options), function(x){
     if(! (x %in% c("width", "height") & 
-            ! is.numeric(type.convert(gsub("px","", options[[x]])))) 
+            ! is.numeric(type.convert(gsub("px","", options[[x]]), as.is = TRUE))) 
   ){
-   
       paste("options[\"", x,"\"] = ",
             ifelse(any(checkSquareCurlBracketOps(options[[x]])),
                    paste(options[[x]], collapse="\n"),
@@ -605,7 +618,7 @@ body {
   if(type %in% "gvisMerge"){
     policy <- "Data Policy: See individual charts"
   }else{
-    policy <- sprintf('<a href="https://google-developers.appspot.com/chart/interactive/docs/gallery/%s">Documentation and Data Policy</a>', type)
+    policy <- sprintf('<a href="https://developers.google.com/chart/interactive/docs/gallery/%s">Documentation and Data Policy</a>', type)
   }
   
   htmlFooter <- sprintf(htmlFooter, R.Version()$version.string,
